@@ -37,13 +37,13 @@ static struct {
 } local;
 
 typedef struct {
-    char * string;
+    const char * string;
     int    isboolean;
-    char * description;
+    const char * description;
     int  * p;
 } Switch;
 
-Switch default_switches[] = {
+static Switch default_switches[] = {
     {"verbosity",    0, "Level of detail in output",        &local.verbosity},
     {"timeout",      0, "Abort parsing after this long",    &local.timeout},
     {"memory",       0, "Max memory allowed",               &local.memory},
@@ -67,13 +67,13 @@ Switch default_switches[] = {
     {NULL,           1,  NULL,                              NULL}
 };
 
-struct {char * s; char * str;} user_command[] = {
+struct {const char * s; const char * str;} user_command[] = {
     {"variables",    "List user-settable variables and their functions"},
     {"help",         "List the commands and what they do"},
     {NULL,           NULL}
 };
 
-void clean_up_string(char * s) {
+static void clean_up_string(char * s) {
     /* gets rid of all the white space in the string s.  Changes s */
     char * x, * y;
     y = x = s;
@@ -87,7 +87,7 @@ void clean_up_string(char * s) {
     *y = '\0';
 }
 
-int is_numerical_rhs(char *s) {
+static int is_numerical_rhs(char *s) {
     /* return TRUE if s points to a number:
      optional + or - followed by 1 or more
      digits.
@@ -98,7 +98,7 @@ int is_numerical_rhs(char *s) {
     return TRUE;
 }
 
-void x_issue_special_command(char * line, Parse_Options opts, Dictionary dict) {
+static void x_issue_special_command(char * line, Parse_Options opts, Dictionary dict) {
     char *s, myline[1000], *x, *y;
     int i, count, j, k;
     Switch * as = default_switches;
@@ -207,7 +207,7 @@ void x_issue_special_command(char * line, Parse_Options opts, Dictionary dict) {
     printf("I can't interpret \"%s\" as a command.  Try \"!help\".\n", myline);
 }
 
-void put_opts_in_local_vars(Parse_Options opts) {
+static void put_opts_in_local_vars(Parse_Options opts) {
     local.verbosity = parse_options_get_verbosity(opts);
     local.timeout = parse_options_get_max_parse_time(opts);;
     local.memory = parse_options_get_max_memory(opts);;
@@ -231,7 +231,7 @@ void put_opts_in_local_vars(Parse_Options opts) {
     local.display_union = parse_options_get_display_union(opts);
 }
 
-void put_local_vars_in_opts(Parse_Options opts) {
+static void put_local_vars_in_opts(Parse_Options opts) {
     parse_options_set_verbosity(opts, local.verbosity);
     parse_options_set_max_parse_time(opts, local.timeout);
     parse_options_set_max_memory(opts, local.memory);
